summaryrefslogtreecommitdiffstats
path: root/kmymoney2/mymoney/mymoneyreport.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/mymoney/mymoneyreport.h')
-rw-r--r--kmymoney2/mymoney/mymoneyreport.h92
1 files changed, 46 insertions, 46 deletions
diff --git a/kmymoney2/mymoney/mymoneyreport.h b/kmymoney2/mymoney/mymoneyreport.h
index e467179..a541042 100644
--- a/kmymoney2/mymoney/mymoneyreport.h
+++ b/kmymoney2/mymoney/mymoneyreport.h
@@ -24,11 +24,11 @@
// ----------------------------------------------------------------------------
// QT Includes
-#include <qmap.h>
-#include <qvaluelist.h>
-#include <qstring.h>
-class QDomElement;
-class QDomDocument;
+#include <tqmap.h>
+#include <tqvaluelist.h>
+#include <tqstring.h>
+class TQDomElement;
+class TQDomDocument;
// ----------------------------------------------------------------------------
// Project Includes
@@ -45,8 +45,8 @@ class QDomDocument;
* A report is a transactionfilter, so any report can specify which
* transactions it's interested down to the most minute level of detail.
* It extends the transactionfilter by providing identification (name,
- * comments, group type, etc) as well as layout information (what kind
- * of layout should be used, how the rows & columns should be presented,
+ * comments, group type, etc) as well as tqlayout information (what kind
+ * of tqlayout should be used, how the rows & columns should be presented,
* currency converted, etc.)
*
* As noted above, this class only provides a report DEFINITION. The
@@ -64,34 +64,34 @@ public:
enum EReportType { eNoReport = 0, ePivotTable, eQueryTable, eInfoTable };
enum EColumnType { eNoColumns = 0, eDays = 1, eMonths = 1, eBiMonths = 2, eQuarters = 3, eWeeks = 7, eYears = 12 };
- // if you add bits to this bitmask, start with the value currently assigned to eQCend and update its value afterwards
+ // if you add bits to this bittqmask, start with the value currently assigned to eTQCend and update its value afterwards
// also don't forget to add column names to kQueryColumnsText in mymoneyreport.cpp
- enum EQueryColumns { eQCnone = 0x0, eQCbegin = 0x1, eQCnumber = 0x1, eQCpayee = 0x2, eQCcategory = 0x4, eQCmemo = 0x8, eQCaccount = 0x10, eQCreconciled = 0x20, eQCaction = 0x40, eQCshares = 0x80, eQCprice = 0x100, eQCperformance = 0x200, eQCloan = 0x400, eQCbalance = 0x800, eQCend = 0x1000 };
+ enum EQueryColumns { eTQCnone = 0x0, eTQCbegin = 0x1, eTQCnumber = 0x1, eTQCpayee = 0x2, eTQCcategory = 0x4, eTQCmemo = 0x8, eTQCaccount = 0x10, eTQCreconciled = 0x20, eTQCaction = 0x40, eTQCshares = 0x80, eTQCprice = 0x100, eTQCperformance = 0x200, eTQCloan = 0x400, eTQCbalance = 0x800, eTQCend = 0x1000 };
enum EDetailLevel { eDetailNone = 0, eDetailAll, eDetailTop, eDetailGroup, eDetailTotal, eDetailEnd };
enum EChartType { eChartNone = 0, eChartLine, eChartBar, eChartPie, eChartRing, eChartStackedBar, eChartEnd };
- static const QStringList kRowTypeText;
- static const QStringList kColumnTypeText;
- static const QStringList kQueryColumnsText;
- static const QStringList kDetailLevelText;
- static const QStringList kChartTypeText;
+ static const TQStringList kRowTypeText;
+ static const TQStringList kColumnTypeText;
+ static const TQStringList kQueryColumnsText;
+ static const TQStringList kDetailLevelText;
+ static const TQStringList kChartTypeText;
static const EReportType kTypeArray[];
public:
MyMoneyReport(void);
- MyMoneyReport(ERowType _rt, unsigned _ct, dateOptionE _dl, EDetailLevel _ss, const QString& _name, const QString& _comment );
- MyMoneyReport(const QString& id, const MyMoneyReport& right);
+ MyMoneyReport(ERowType _rt, unsigned _ct, dateOptionE _dl, EDetailLevel _ss, const TQString& _name, const TQString& _comment );
+ MyMoneyReport(const TQString& id, const MyMoneyReport& right);
/**
* This constructor creates an object based on the data found in the
* QDomElement referenced by @p node. If problems arise, the @p id of
* the object is cleared (see MyMoneyObject::clearId()).
*/
- MyMoneyReport(const QDomElement& node);
+ MyMoneyReport(const TQDomElement& node);
// Simple get operations
- const QString& name(void) const { return m_name; }
+ const TQString& name(void) const { return m_name; }
bool isShowingRowTotals(void) const { return (m_showRowTotals); }
EReportType reportType(void) const { return m_reportType; }
ERowType rowType(void) const { return m_rowType; }
@@ -100,9 +100,9 @@ public:
bool isConvertCurrency(void) const { return m_convertCurrency; }
unsigned columnPitch(void) const { return static_cast<unsigned>(m_columnType); }
bool isShowingColumnTotals(void) const { return m_convertCurrency; }
- const QString& comment( void ) const { return m_comment; }
+ const TQString& comment( void ) const { return m_comment; }
EQueryColumns queryColumns(void) const { return m_queryColumns; }
- const QString& group( void ) const { return m_group; }
+ const TQString& group( void ) const { return m_group; }
bool isFavorite(void) const { return m_favorite; }
bool isTax(void) const { return m_tax; }
bool isInvestmentsOnly(void) const { return m_investments; }
@@ -118,7 +118,7 @@ public:
bool isIncludingTransfers(void) const { return m_includeTransfers; }
bool isIncludingUnusedAccounts(void) const { return m_includeUnusedAccounts; }
bool hasBudget(void) const { return !m_budgetId.isEmpty(); }
- const QString& budget(void) const { return m_budgetId; }
+ const TQString& budget(void) const { return m_budgetId; }
bool isIncludingBudgetActuals(void) const { return m_includeBudgetActuals; }
bool isIncludingForecast(void) const { return m_includeForecast; }
bool isIncludingMovingAverage(void) const { return m_includeMovingAverage; }
@@ -128,12 +128,12 @@ public:
bool isUserDefined(void) const { return m_dateLock == userDefined; }
// Simple set operations
- void setName(const QString& _s) { m_name = _s; }
+ void setName(const TQString& _s) { m_name = _s; }
void setConvertCurrency(bool _f) { m_convertCurrency = _f; }
void setRowType(ERowType _rt);
void setColumnType(EColumnType _ct) { m_columnType = _ct; }
- void setComment( const QString& _comment ) { m_comment = _comment; }
- void setGroup( const QString& _group ) { m_group = _group; }
+ void setComment( const TQString& _comment ) { m_comment = _comment; }
+ void setGroup( const TQString& _group ) { m_group = _group; }
void setFavorite(bool _f) { m_favorite = _f; }
void setQueryColumns( EQueryColumns _qc ) { m_queryColumns = _qc; }
void setTax(bool _f) { m_tax = _f; }
@@ -168,7 +168,7 @@ public:
* simply checked for any non-empty string, and if so, hasBudget()
* will return true.
*/
- void setBudget( const QString& _budget, bool _fa = true ) { m_budgetId = _budget; m_includeBudgetActuals=_fa; }
+ void setBudget( const TQString& _budget, bool _fa = true ) { m_budgetId = _budget; m_includeBudgetActuals=_fa; }
/**
* This method allows you to clear the underlying transaction filter
@@ -212,7 +212,7 @@ public:
* @param _de The inclusive end date of the date range
*/
- void setDateFilter(const QDate& _db,const QDate& _de) { MyMoneyTransactionFilter::setDateFilter( _db,_de ); }
+ void setDateFilter(const TQDate& _db,const TQDate& _de) { MyMoneyTransactionFilter::setDateFilter( _db,_de ); }
/**
* Set the underlying date filter using the 'date lock' property.
@@ -230,19 +230,19 @@ public:
/**
* Retrieves a VALID beginning & ending date for this report.
*
* The underlying date filter can return en empty QDate() for either the
* begin or end date or both. This is typically unacceptable for reports,
* which need the REAL begin and end date.
*
* This function gets the underlying date filter range, and if either is
* an empty QDate(), it determines the missing date from looking at all
* the transactions which match the underlying filter, and returning the
* date of the first or last transaction (as appropriate).
*
* @param _db The inclusive begin date of the date range
* @param _de The inclusive end date of the date range
*/
- void validDateRange(QDate& _db, QDate& _de);
+ void validDateRange(TQDate& _db, TQDate& _de);
/**
* This method turns on the account group filter and adds the
@@ -251,7 +251,7 @@ public:
* Note that account group filtering is handled differently
* than all the filters of the underlying class. This filter
* is meant to be applied to individual splits of matched
- * transactions AFTER the underlying filter is used to find
+ * transactions AFTER the underlying filter is used to tqfind
* the matching transactions.
*
* @param type the account group to add to the allowed groups list
@@ -265,7 +265,7 @@ public:
* @param list list to append account groups into
* @return return true if an account group filter has been set
*/
- bool accountGroups(QValueList<MyMoneyAccount::accountTypeE>& list) const;
+ bool accountGroups(TQValueList<MyMoneyAccount::accountTypeE>& list) const;
/**
* This method returns whether the specified account group
@@ -296,9 +296,9 @@ public:
* @param doc The document which we can use to create new sub-elements
* if needed
* @param anonymous Whether the sensitive parts of the report should be
- * masked
+ * tqmasked
*/
- void write(QDomElement& e, QDomDocument *doc, bool anonymous=false) const;
+ void write(TQDomElement& e, TQDomDocument *doc, bool anonymous=false) const;
/**
* This method reads a report from the DOM element @p e, and
@@ -310,17 +310,17 @@ public:
* element @p e. If false is returned, the contents of this report
* object are undefined.
*/
- bool read(const QDomElement& e);
+ bool read(const TQDomElement& e);
/**
* This method creates a QDomElement for the @p document
* under the parent node @p parent. (This version overwrites the
* MMObject base class.)
*
* @param document reference to QDomDocument
* @param parent reference to QDomElement parent node
*/
- virtual void writeXML(QDomDocument& document, QDomElement& parent) const;
+ virtual void writeXML(TQDomDocument& document, TQDomElement& tqparent) const;
/**
* This method checks if a reference to the given object exists. It returns,
@@ -331,23 +331,23 @@ public:
* @retval true This object references object with id @p id.
* @retval false This object does not reference the object with id @p id.
*/
- virtual bool hasReferenceTo(const QString& id) const;
+ virtual bool hasReferenceTo(const TQString& id) const;
private:
/**
* The user-assigned name of the report
*/
- QString m_name;
+ TQString m_name;
/**
* The user-assigned comment for the report, in case they want to make
* additional notes for themselves about the report.
*/
- QString m_comment;
+ TQString m_comment;
/**
* Where to group this report amongst the others in the UI view. This
* should be assigned by the UI system.
*/
- QString m_group;
+ TQString m_group;
/**
* How much detail to show in the accounts
*/
@@ -417,7 +417,7 @@ private:
* is applied to the individual splits AFTER a transaction has been
* matched using the underlying filter.
*/
- QValueList<MyMoneyAccount::accountTypeE> m_accountGroups;
+ TQValueList<MyMoneyAccount::accountTypeE> m_accountGroups;
/**
* Whether an account group filter has been set (see m_accountGroups)
*/
@@ -454,7 +454,7 @@ private:
/**
* The id of the budget associated with this report.
*/
- QString m_budgetId;
+ TQString m_budgetId;
/**
* Whether this report should print the actual data to go along with
* the budget. This is only valid if the report has a budget.
@@ -64,34 +64,34 @@ public:
/**
* This constructor creates an object based on the data found in the
- * QDomElement referenced by @p node. If problems arise, the @p id of
+ * TQDomElement referenced by @p node. If problems arise, the @p id of
* the object is cleared (see MyMoneyObject::clearId()).
*/
@@ -230,19 +230,19 @@ public:
* Retrieves a VALID beginning & ending date for this report.
*
- * The underlying date filter can return en empty QDate() for either the
+ * The underlying date filter can return en empty TQDate() for either the
* begin or end date or both. This is typically unacceptable for reports,
* which need the REAL begin and end date.
@@ -230,19 +230,19 @@ public:
*
* This function gets the underlying date filter range, and if either is
- * an empty QDate(), it determines the missing date from looking at all
+ * an empty TQDate(), it determines the missing date from looking at all
* the transactions which match the underlying filter, and returning the
* date of the first or last transaction (as appropriate).
@@ -310,17 +310,17 @@ public:
/**
- * This method creates a QDomElement for the @p document
- * under the parent node @p parent. (This version overwrites the
+ * This method creates a TQDomElement for the @p document
+ * under the tqparent node @p tqparent. (This version overwrites the
* MMObject base class.)
*
@@ -310,17 +310,17 @@ public:
* MMObject base class.)
*
- * @param document reference to QDomDocument
- * @param parent reference to QDomElement parent node
+ * @param document reference to TQDomDocument
+ * @param tqparent reference to TQDomElement tqparent node
*/